@@ -1,6 +1,4 @@
 import numbers
-import os
-import tempfile
 from collections.abc import Iterable
 from pathlib import Path
 from typing import List, Optional, Tuple, Union
@@ -18,8 +16,11 @@ from paramak.utils import (
     facet_wire,
     get_hash,
     intersect_solid,
-    plotly_trace,
     union_solid,
+    get_largest_dimension,
+    get_bounding_box,
+    export_solids_to_brep,
+    export_solids_to_dagmc_h5m,
 )
 
 
@@ -214,39 +215,28 @@ class Shape:
         self._union = value
 
     @property
-    def largest_dimension(self):
-        """Calculates a bounding box for the Shape and returns the largest
+    def largest_dimension(self) -> float:
+        """Calculates a bounding box for the Reactor and returns the largest
         absolute value of the largest dimension of the bounding box"""
-        largest_dimension = 0
-        if isinstance(self.solid, (Compound, shapes.Solid)):
-            for solid in self.solid.Solids():
-                bound_box = solid.BoundingBox()
-                largest_dimension = max(
-                    abs(bound_box.xmax),
-                    abs(bound_box.xmin),
-                    abs(bound_box.ymax),
-                    abs(bound_box.ymin),
-                    abs(bound_box.zmax),
-                    abs(bound_box.zmin),
-                    largest_dimension,
-                )
-        else:
-            bound_box = self.solid.val().BoundingBox()
-            largest_dimension = max(
-                abs(bound_box.xmax),
-                abs(bound_box.xmin),
-                abs(bound_box.ymax),
-                abs(bound_box.ymin),
-                abs(bound_box.zmax),
-                abs(bound_box.zmin),
-            )
-        self.largest_dimension = largest_dimension
-        return largest_dimension
+
+        return get_largest_dimension(self.solid)
 
     @largest_dimension.setter
     def largest_dimension(self, value):
         self._largest_dimension = value
 
+    @property
+    def bounding_box(self):
+        """Calculates a bounding box for the Shape and returns the coordinates of
+        the corners lower-left and upper-right. This function is useful when
+        creating OpenMC mesh tallies as the bounding box is required in this form"""
+
+        return get_bounding_box(self.solid)
+
+    @bounding_box.setter
+    def bounding_box(self, value):
+        self._bounding_box = value
+
     @property
     def workplane(self):
         return self._workplane
@@ -260,13 +250,9 @@ class Shape:
             if value in acceptable_values:
                 self._workplane = value
             else:
-                raise ValueError(
-                    "Shape.workplane must be one of ", acceptable_values, " not ", value
-                )
+                raise ValueError("Shape.workplane must be one of ", acceptable_values, " not ", value)
         else:
-            raise TypeError(
-                "Shape.workplane must be a string or a ", "cadquery.Plane object"
-            )
+            raise TypeError("Shape.workplane must be a string or a ", "cadquery.Plane object")
 
     @property
     def rotation_axis(self):
@@ -277,31 +263,29 @@ class Shape:
         if isinstance(value, str):
             acceptable_values = ["X", "Y", "Z", "-X", "-Y", "-Z", "+X", "+Y", "+Z"]
             if value not in acceptable_values:
-                msg = (
-                    "Shape.rotation_axis must be one of "
-                    + " ".join(acceptable_values)
-                    + " not "
-                    + value
-                )
+                msg = "Shape.rotation_axis must be one of " + " ".join(acceptable_values) + " not " + value
                 raise ValueError(msg)
         elif isinstance(value, Iterable):
             msg = "Shape.rotation_axis must be a tuple of three floats (X, Y, Z)"
             if len(value) != 2:
                 raise ValueError(msg)
             for point in value:
-                if not isinstance(point, tuple):
+                if not isinstance(point, Iterable):
+                    msg = f"Shape.rotation_axis must be an iterable of iterables, not {type(point)}"
                     raise ValueError(msg)
                 if len(point) != 3:
+                    msg = f"Shape.rotation_axis must be an iterable of iterables with 3 entries, not {len(point)}"
                     raise ValueError(msg)
                 for val in point:
                     if not isinstance(val, (int, float)):
+                        msg = f"Shape.rotation_axis should be an iterable of iterables where the nested iterables are numerical, not {type(val)}"
                         raise ValueError(msg)
 
             if value[0] == value[1]:
-                msg = "The two points must be different"
+                msg = "The two coordinates points for rotation_axis must be different"
                 raise ValueError(msg)
         elif value is not None:
-            msg = "Shape.rotation_axis must be a list or a string or None"
+            msg = "Shape.rotation_axis must be an iterable or a string or None"
             raise ValueError(msg)
         self._rotation_axis = value
 
@@ -353,15 +337,9 @@ class Shape:
             if len(value) in [3, 4]:
                 for i in value:
                     if not isinstance(i, (int, float)):
-                        raise ValueError(
-                            "Individual entries in the Shape.color must a "
-                            "number (float or int)"
-                        )
+                        raise ValueError("Individual entries in the Shape.color must a " "number (float or int)")
                     if i > 1 or i < 0:
-                        raise ValueError(
-                            "Individual entries in the Shape.color must be "
-                            "between 0 and 1"
-                        )
+                        raise ValueError("Individual entries in the Shape.color must be " "between 0 and 1")
             else:
                 raise ValueError("Shape.color must be a list or tuple of 3 or 4 floats")
         else:
@@ -420,9 +398,7 @@ class Shape:
             incorrect type: only list of lists or tuples are accepted
         """
         ignored_keys = ["_points", "_points_hash_value"]
-        if self.find_points() and self.points_hash_value != get_hash(
-            self, ignored_keys
-        ):
+        if self.find_points() and self.points_hash_value != get_hash(self, ignored_keys):
             self.find_points()
             self.points_hash_value = get_hash(self, ignored_keys)
 
@@ -440,18 +416,13 @@ class Shape:
 
             for value in values:
                 if not isinstance(value, (list, tuple)):
-                    msg = (
-                        f"individual points must be a tuple.{value} in of "
-                        f"type {type(value)}"
-                    )
+                    msg = f"individual points must be a tuple.{value} in of " f"type {type(value)}"
                     raise ValueError(msg)
 
             for counter, value in enumerate(values):
                 if self.connection_type == "mixed":
                     if len(value) != 3:
-                        if (
-                            counter != len(values) - 1
-                        ):  # last point doesn't need connections
+                        if counter != len(values) - 1:  # last point doesn't need connections
                             msg = (
                                 "individual points should contain 3 "
                                 "entries when the Shape.connection_type is "
@@ -492,17 +463,12 @@ class Shape:
                 # part of points
                 if len(value) == 3:
                     if value[2] not in ["straight", "spline", "circle"]:
-                        msg = (
-                            "individual connections must be either "
-                            '"straight", "circle" or "spline"'
-                        )
+                        msg = "individual connections must be either " '"straight", "circle" or "spline"'
                         raise ValueError(msg)
 
             if len(values) > 1:
                 if values[0][:2] == values[-1][:2]:
-                    msg = (
-                        "The coordinates of the last and first points are " "the same."
-                    )
+                    msg = "The coordinates of the last and first points are " "the same."
                     raise ValueError(msg)
 
         self._points = values
@@ -569,9 +535,7 @@ class Shape:
         scaled_color = [int(i * 255) for i in self.color[0:3]]
         if isinstance(self.solid, (shapes.Shape, shapes.Compound)):
             for i, solid in enumerate(self.solid.Solids()):
-                parts.append(
-                    Part(solid, name=f"{name}{i}", color=scaled_color, show_edges=True)
-                )
+                parts.append(Part(solid, name=f"{name}{i}", color=scaled_color, show_edges=True))
         else:
             parts.append(
                 Part(
@@ -621,26 +585,18 @@ class Shape:
 
                 if self.force_cross_section:
                     for point in self.path_points[:-1]:
-                        solid = (
-                            solid.workplane(offset=point[1] * factor)
-                            .center(point[0], 0)
-                            .workplane()
-                        )
+                        solid = solid.workplane(offset=point[1] * factor).center(point[0], 0).workplane()
                         for entry in instructions:
                             connection_type = list(entry.keys())[0]
                             if connection_type == "spline":
-                                solid = solid.spline(
-                                    listOfXYTuple=list(entry.values())[0]
-                                )
+                                solid = solid.spline(listOfXYTuple=list(entry.values())[0])
                             elif connection_type == "straight":
                                 solid = solid.polyline(list(entry.values())[0])
                             elif connection_type == "circle":
                                 p0, p1, p2 = list(entry.values())[0][:3]
                                 solid = solid.moveTo(p0[0], p0[1]).threePointArc(p1, p2)
                         solid = solid.close()
-                        solid = solid.center(-point[0], 0).workplane(
-                            offset=-point[1] * factor
-                        )
+                        solid = solid.center(-point[0], 0).workplane(offset=-point[1] * factor)
 
                 elif self.force_cross_section is False:
                     solid = (
@@ -822,40 +778,53 @@ class Shape:
 
         return str(path_filename)
 
-    def export_brep(self, filename):
-        """Exports a brep file for the Shape.solid.
+    def export_brep(self, filename="shape.brep", include_graveyard=False) -> str:
+        """Exports a brep file for the Shape. Optionally including a DAGMC
+        graveyard.
 
         Args:
             filename: the filename of exported the brep file.
+            include_graveyard: specify if the graveyard will be included or
+                not. If True the the Shape.make_graveyard will be called
+                using Shape.graveyard_size and Shape.graveyard_offset
+                attribute values.
+
+        Returns:
+            filename of the brep created
         """
 
-        path_filename = Path(filename)
+        geometry_to_save = [self.solid]
 
-        if path_filename.suffix != ".brep":
-            msg = "When exporting a brep file the filename must end with .brep"
-            raise ValueError(msg)
+        if include_graveyard:
+            self.make_graveyard()
+            geometry_to_save.append(self.graveyard.solid)
 
-        path_filename.parents[0].mkdir(parents=True, exist_ok=True)
+        output_filename = export_solids_to_brep(
+            solids=geometry_to_save,
+            filename=filename,
+        )
 
-        self.solid.val().exportBrep(str(path_filename))
-        # alternative method is to use BRepTools that might support imprinting
-        # and merging https://github.com/CadQuery/cadquery/issues/449
-        # from OCP.BRepTools import BRepTools
-        # BRepTools.Write_s(self.solid.toOCC(), str(path_filename))
-
-        return str(path_filename)
+        return output_filename
 
     def export_dagmc_h5m(
         self,
         filename: str = "dagmc.h5m",
-        min_mesh_size: float = 10,
+        min_mesh_size: float = 5,
         max_mesh_size: float = 20,
+        verbose: bool = False,
+        volume_atol: float = 0.000001,
+        center_atol: float = 0.000001,
+        bounding_box_atol: float = 0.000001,
+        tags: Optional[List[str]] = None,
+        include_graveyard: bool = False,
     ) -> str:
         """Export a DAGMC compatible h5m file for use in neutronics simulations.
         This method makes use of Gmsh to create a surface mesh of the geometry.
         MOAB is used to convert the meshed geometry into a h5m with parts tagged by
         using the reactor.shape_and_components.name properties. You will need
-        Gmsh installed and MOAB installed to use this function.
+        Gmsh installed and MOAB installed to use this function. Acceptable
+        tolerances may need increasing to match reactor parts with the parts
+        in the intermediate Brep file produced during the process
 
         Args:
             filename: the filename of the DAGMC h5m file to write
@@ -863,31 +832,48 @@ class Shape:
                 into gmsh.option.setNumber("Mesh.MeshSizeMin", min_mesh_size)
             max_mesh_size: the maximum mesh element size to use in Gmsh. Passed
                 into gmsh.option.setNumber("Mesh.MeshSizeMax", max_mesh_size)
+            volume_atol: the absolute volume tolerance to allow when matching
+                parts in the intermediate brep file with the cadquery parts
+            center_atol: the absolute center coordinates tolerance to allow
+                when matching parts in the intermediate brep file with the
+                cadquery parts
+            bounding_box_atol: the absolute volume tolerance to allow when
+                matching parts in the intermediate brep file with the cadquery
+                parts
+            tags: the dagmc tag to use in when naming the shape in the h5m file.
+                If left as None then the Shape.name will be used. This allows
+                the DAGMC geometry created to be compatible with a wider range
+                of neutronics codes that have specific DAGMC tag requirements.
+            include_graveyard: specify if the graveyard will be included or
+                not. If True the the Reactor.make_graveyard will be called
+                using Reactor.graveyard_size and Reactor.graveyard_offset
+                attribute values.
         """
 
-        from brep_to_h5m import brep_to_h5m
+        shapes_to_convert = [self.solid]
 
-        tmp_brep_filename = tempfile.mkstemp(suffix=".brep", prefix="paramak_")[1]
+        if include_graveyard:
+            self.make_graveyard()
+            shapes_to_convert.append(self.graveyard.solid)
 
-        # saves the reactor as a Brep file with merged surfaces
-        self.export_brep(tmp_brep_filename)
+        if tags is None:
+            tags = [self.name]
+            if include_graveyard:
+                tags.append(self.graveyard.name)
 
-        volumes_with_tags = {}
-        for counter, _ in enumerate(self.solid.val().Solids(), 1):
-            volumes_with_tags[counter] = f"mat_{self.name}"
-
-        brep_to_h5m(
-            brep_filename=tmp_brep_filename,
-            volumes_with_tags=volumes_with_tags,
-            h5m_filename=filename,
+        output_filename = export_solids_to_dagmc_h5m(
+            solids=shapes_to_convert,
+            filename=filename,
             min_mesh_size=min_mesh_size,
             max_mesh_size=max_mesh_size,
+            verbose=verbose,
+            volume_atol=volume_atol,
+            center_atol=center_atol,
+            bounding_box_atol=bounding_box_atol,
+            tags=tags,
         )
 
-        # temporary brep is deleted
-        os.remove(tmp_brep_filename)
-
-        return filename
+        return output_filename
 
     def export_stp(
         self,
@@ -1098,25 +1084,9 @@ class Shape:
             facet_splines=facet_splines,
             facet_circles=facet_circles,
             tolerance=tolerance,
-            title=(
-                f"coordinates of {self.__class__.__name__} shape, viewed "
-                "from the {view_plane} plane"
-            ),
+            title=f"coordinates of {self.__class__.__name__} shape, viewed from the {view_plane} plane",
         )
 
-        if self.points is not None:
-            fig.add_trace(
-                plotly_trace(points=self.points, mode="markers", name="Shape.points")
-            )
-
-        # sweep shapes have .path_points but not .points attribute
-        if self.path_points:
-            fig.add_trace(
-                plotly_trace(
-                    points=self.path_points, mode="markers", name="Shape.path_points"
-                )
-            )
-
         if filename is not None:
 
             Path(filename).parents[0].mkdir(parents=True, exist_ok=True)
@@ -1278,9 +1248,7 @@ class Shape:
 
         elif self.graveyard_offset is not None:
             self.solid
-            graveyard_size_to_use = (
-                self.largest_dimension * 2 + self.graveyard_offset * 2
-            )
+            graveyard_size_to_use = self.largest_dimension * 2 + self.graveyard_offset * 2
 
         else:
             raise ValueError(
@@ -1350,9 +1318,7 @@ class Shape:
                 p_1 = self.processed_points[counter + 1][:2]
                 p_2 = self.processed_points[counter + 2][:2]
 
-                points = paramak.utils.convert_circle_to_spline(
-                    p_0, p_1, p_2, tolerance=tolerance
-                )
+                points = paramak.utils.convert_circle_to_spline(p_0, p_1, p_2, tolerance=tolerance)
 
                 # the last point needs to have the connection type of p2
                 for point in points[:-1]:
