@@ -1,19 +1,18 @@
-
 import unittest
 
-import paramak
 import pytest
 
+import paramak
+
 
 class TestCoolantChannelRingCurved(unittest.TestCase):
-
     def setUp(self):
         self.test_shape = paramak.CoolantChannelRingCurved(
             height=100,
             channel_radius=10,
             ring_radius=70,
             mid_offset=-20,
-            number_of_coolant_channels=6
+            number_of_coolant_channels=6,
         )
 
     def test_default_parameters(self):
@@ -47,10 +46,6 @@ class TestCoolantChannelRingCurved(unittest.TestCase):
         """Checks that the coolant channels are placed at the correct azimuthal placement
         angles for a given start angle."""
 
-        assert self.test_shape.azimuth_placement_angle == [
-            0, 60, 120, 180, 240, 300
-        ]
+        assert self.test_shape.azimuth_placement_angle == [0, 60, 120, 180, 240, 300]
         self.test_shape.start_angle = 10
-        assert self.test_shape.azimuth_placement_angle == [
-            10, 70, 130, 190, 250, 310
-        ]
+        assert self.test_shape.azimuth_placement_angle == [10, 70, 130, 190, 250, 310]
